@@ -1,8 +1,8 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python3 
 # coding: utf-8
 # /*##########################################################################
 #
-# Copyright (c) 2015-2021 European Synchrotron Radiation Facility
+# Copyright (c) 2015-2023 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -52,11 +52,11 @@ Thus 2.1.0a3 is hexversion 0x020100a3.
 __authors__ = ["Jérôme Kieffer"]
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "25/01/2021"
+__date__ = "11/09/2024"
 __status__ = "production"
 __docformat__ = 'restructuredtext'
 __all__ = ["date", "version_info", "strictversion", "hexversion", "debianversion",
-           "calc_hexversion"]
+           "calc_hexversion", "citation"]
 
 RELEASE_LEVEL_VALUE = {"dev": 0,
                        "alpha": 10,
@@ -68,7 +68,7 @@ PRERELEASE_NORMALIZED_NAME = {"dev": "a",
                               "alpha": "a",
                               "beta": "b",
                               "candidate": "rc"}
-MAJOR = 0
+MAJOR = 2024
 MINOR = 9
 MICRO = 0
 RELEV = "final"  # <16
@@ -77,6 +77,7 @@ SERIAL = 0  # <16
 date = __date__
 
 from collections import namedtuple
+
 _version_info = namedtuple("version_info", ["major", "minor", "micro", "releaselevel", "serial"])
 
 version_info = _version_info(MAJOR, MINOR, MICRO, RELEV, SERIAL)
@@ -92,7 +93,8 @@ if version_info.releaselevel != "final":
     strictversion += PRERELEASE_NORMALIZED_NAME[version_info[3]] + str(version_info[-1])
 
 
-def calc_hexversion(major=0, minor=0, micro=0, releaselevel="dev", serial=0):
+
+def calc_hexversion(major=0, minor=0, micro=0, releaselevel="dev", serial=0, string=None):
     """Calculate the hexadecimal version number from the tuple version_info:
 
     :param major: integer
@@ -100,8 +102,23 @@ def calc_hexversion(major=0, minor=0, micro=0, releaselevel="dev", serial=0):
     :param micro: integer
     :param relev: integer or string
     :param serial: integer
+    :param string: version number as a string
     :return: integer always increasing with revision numbers
     """
+    if string is not None:
+        global _PATTERN
+        if _PATTERN is None:
+            import re
+            _PATTERN = re.compile(r"(\d+)\.(\d+)\.(\d+)(\w+)?$")
+        result = _PATTERN.match(string)
+        if result is None:
+            raise ValueError("'%s' is not a valid version" % string)
+        result = result.groups()
+        major, minor, micro = int(result[0]), int(result[1]), int(result[2])
+        releaselevel = result[3]
+        if releaselevel is None:
+            releaselevel = 0
+
     try:
         releaselevel = int(releaselevel)
     except ValueError:
@@ -117,5 +134,20 @@ def calc_hexversion(major=0, minor=0, micro=0, releaselevel="dev", serial=0):
 
 hexversion = calc_hexversion(*version_info)
 
+citation = "doi:10.1107/S1600577522007238"
+
 if __name__ == "__main__":
-    print(version)
+    from argparse import ArgumentParser
+
+    parser = ArgumentParser(usage="print the version of the software")
+    parser.add_argument("--wheel", action="store_true", dest="wheel", default=None,
+                        help="print version formated for wheel")
+    parser.add_argument("--debian", action="store_true", dest="debian", default=None,
+                        help="print version formated for debian")
+    options = parser.parse_args()
+    if options.debian:
+        print(debianversion)
+    elif options.wheel:
+        print(strictversion)
+    else:
+        print(version)
